@@ -10,7 +10,7 @@ use IO::Socket::IP -register;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.32'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 sub new {
     my $class = shift;
@@ -84,7 +84,8 @@ sub run {
         );
     }
     catch {
-        croak("Daemon device instantiation failure: $_");
+        my $e = $_ || $@;
+        croak("Daemon device instantiation failure: $e");
     };
 
     $self->{device}->run;
@@ -134,7 +135,8 @@ sub _parent {
                 $_->{code}->($self);
             }
             catch {
-                warn "Tick execution failure: $_\n";
+                my $e = $_ || $@;
+                warn "Tick execution failure: $e\n";
             };
         }
     };
@@ -211,7 +213,8 @@ sub _parent {
         }
     }
     catch {
-        warn "Daemon parent loop failure: $_\n";
+        my $e = $_ || $@;
+        warn "Daemon parent loop failure: $e\n";
         kill( 'KILL', $_ ) for ( @{ $device->children } );
     };
 }
@@ -398,7 +401,8 @@ sub _on_message {
                 );
             }
             catch {
-                warn "Plugin hook execution failure: $_\n";
+                my $e = $_ || $@;
+                warn "Plugin hook execution failure: $e\n";
             };
 
             last if ($rv);
@@ -676,7 +680,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.32
+version 1.33
 
 =for markdown [![test](https://github.com/gryphonshafer/Bot-IRC/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bot-IRC/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Bot-IRC/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bot-IRC)
